*==============================================================================*
// Imputación de ingresos en ECH y EUT 2021/2022
// Método 1: regresión por decil del INSE
// Paula Barro
// Diciembre 2024
*==============================================================================*

clear all
set more off
   
local user=1 // 1=Paula

if `user'==1 {
global base "C:\Users\Paula Barro\Dropbox\Paula"
}


***********************************
********** ECH 2021/2022 **********
***********************************


****************************************************************
***** PREPARACIÓN BASE: MISMOS MESES Y LOCALIDADES QUE EUT *****
****************************************************************

use "$base\p21.dta", clear  


***** Octubre-diciembre 2021 y marzo-mayo 2022 *****

drop if bc_mes==1 
drop if bc_mes==2
drop if bc_mes==3
drop if bc_mes==4
drop if bc_mes==5
drop if bc_mes==6
drop if bc_mes==7
drop if bc_mes==8
drop if bc_mes==9

append using "p22.dta", force generate (p22)

drop if bc_mes==1 & p22==1
drop if bc_mes==2 & p22==1
drop if bc_mes==6 & p22==1
drop if bc_mes==7 & p22==1
drop if bc_mes==8 & p22==1
drop if bc_mes==9 & p22==1
drop if bc_mes==10 & p22==1
drop if bc_mes==11 & p22==1
drop if bc_mes==12 & p22==1

***** Restringir para localidades de más de 5000 habitantes *****

drop if bc_area==3
drop if bc_area==4


************************************************
***** MODIFICACIÓN Y CREACIÓN DE VARIABLES *****
************************************************

gen ech=1
gen sexo=bc_pe2==2
gen edad=e27
gen montevideo=(bc_area==01)
gen empleo=(bc_pobp==2)
gen peso=bc_pesotri/2


***** Nivel educativo *****

gen educacion=1 // sin instrucción y primaria completa e incompleta
replace educacion=2 if e51_4_a>0  & e51_4_a<9 // empezó o terminó liceo
replace educacion=2 if e51_4_b>0  & e51_4_b<9 // empezó o terminó utu
replace educacion=2 if e51_5>0  & e51_5<9 // empezó o terminó liceo superior
replace educacion=2 if e51_6>0  & e51_6<9 // empezó o terminó utu superior
replace educacion=2 if e51_6a>0 & e51_6a<9 // capacitaciones que no acreditan emb o ems
replace educacion=3 if ((e51_8>0 & e51_8<9) |  (e51_9>0 & e51_9<9) | (e51_10>0 & e51_10<9)|  (e51_11>0 & e51_11<9))  // magisterio o profesorado, universidad o similar, completa e incompleta

gen primaria=educacion==1
gen secundaria=educacion==2
gen terciaria=educacion==3


save "$base\ech2021_2022", replace



************************************************
***** MODIFICACIÓN Y CREACIÓN DE VARIABLES *****
************************************************


***** Tipo de hogar *****
*************************

drop e32 e32_1 jefeh conyu conyuh

rename e30 e32

*** Variable jefe de hogar ***

gen jefeh=1

*** Variable hijo ***

gen hijo=0
replace hijo=1 if inrange(e32,3,5)
egen hijoh= max(hijo), by (bc_correlat)

*** Variable cónyuge ***

gen conyu=0
replace conyu=1 if e32==2
egen conyuh= max(conyu), by (bc_correlat)

*** Variable padre/madre/suegro/suegra ***

gen padresue=0  
replace padresue=1 if e32==7 | e32==8
egen padresueh = max(padresue), by (bc_correlat)

*** Variable otro familiar ***

gen otrofam=0
replace otrofam=1 if e32==6 | e32==9 | e32==10 | e32==11 | e32==12
egen otrofamh= max(otrofam), by (bc_correlat)

*** Variable no familiar ***

gen nofam=0
replace nofam=1 if e32==13 | e32==14
egen nofamh= max(nofam), by (bc_correlat)

*** Nuclear monoparental ***

generate tiphog1=0
replace tiphog1=1 if (jefeh==1 & conyuh==0 & hijoh==1 & padresueh==0 & otrofamh==0 & nofamh==0)

*** Nuclear biparental ***

generate tiphog2=0
replace tiphog2=1 if (jefeh==1 & conyuh==1 & hijoh==1 & padresueh==0 & otrofamh==0 & nofamh==0)

*** Compuesto/Extendido ***

generate tiphog3=0
replace tiphog3=1 if (nofamh==1) | ((padresueh==1 | otrofamh==1) & (nofamh==0))

*** Unipersonal ***

generate tiphog4=0
replace tiphog4=1 if ((jefeh==1 & conyuh==0 & padresueh==0 & hijoh==0 & otrofamh==0 & nofamh==0)& e32<14)

*** Parejas sin hijos ***

generate tiphog5=0
replace tiphog5=1 if (jefeh==1 & conyuh==1 & padresueh==0 & hijoh==0 & otrofamh==0 & nofamh==0)

*** Definir variables ***

capture drop
gen tipohogar=.
replace tipohogar=1 if tiphog1==1
replace tipohogar=2 if tiphog2==1
replace tipohogar=3 if tiphog3==1 
replace tipohogar=4 if tiphog4==1
replace tipohogar=5 if tiphog5==1
label define tipohogar 1 "Nuclear monoparental" 2 "Nuclear biparental"  3 "Compuesto/Extendido" 4 "Unipersonal"  5 "Parejas sin hijos"
label values tipohogar tipohogar


***** Índice socioeconómico (INSE) *****
****************************************

gen perinformante=bc_nper==1

*** Barrios de Montevideo y departamentos ***

label define barrio 0 "Interior" 41 "Aguada" 29 "Aires Puros" 43 "Atahualpa" 16 "Banados de Carrasco" 3 "Barrio Sur" 54 "Belvedere" 51 "Brazo Oriental" 9 "Buceo" 40 "Capurro, Bella Vista" 14 "Carrasco" 15 "Carrasco Norte" 36 "Casabo, Pajas Blancas" 30 "Casavalle" 26 "Castro, P. Castellanos" 2 "Centro" 27 "Cerrito" 35 "Cerro" 1 "Ciudad Vieja" 59 "Colon centro y noroeste" 58 "Colon sureste, Abayuba" 53 "Conciliacion" 4 "Cordon" 18 "Flor de Maronas" 22 "Ituzaingo" 44 "Jacinto Vera" 21 "Jardines del Hipodromo" 47 "La Blanqueada" 49 "La Comercial" 45 "La Figurita" 37 "La Paloma, Tomkinson" 38 "La Teja" 46 "Larranaga" 28 "Las Acacias" 19 "Las Canteras" 60 "Lezica, Melilla" 11 "Malvin" 12 "Malvin Norte" 62 "Manga" 32 "Manga, Toledo Chico" 17 "Maronas, Parque Guarani" 25 "Mercado Modelo, Bolivar" 55 "Nuevo Paris" 5 "Palermo" 10 "Parque Batlle, Villa Dolores" 6 "Parque Rodo" 57 "Paso de la Arena" 33 "Paso de las Duranas" 34 "Penarol, Lavalleja" 31 "Piedras Blancas" 8 "Pocitos" 39 "Prado, Nueva Savona" 7 "Punta Carretas" 13 "Punta Gorda" 20 "Punta de Rieles, Bella Italia" 42 "Reducto" 52 "Sayago" 50 "Tres Cruces" 56 "Tres Ombues, Victoria" 23 "Union" 24 "Villa Espanola" 61 "Villa Garcia, Manga Rural" 48 "Villa Munoz, Retiro" , replace
label values barrio barrio

rename barrio barrio85
rename bc_dpto domdepartamento

gen barriodpto=.
replace barriodpto=0 if (barrio85==32) | (barrio85==30) | (barrio85==37) | (domdepartamento==13)
replace barriodpto=1 if (barrio85==16) | (barrio85==61) | (barrio85==56) | (barrio85==31) | (barrio85==28) | (domdepartamento==2)
replace barriodpto=2 if (barrio85==57) | (barrio85==62) | (barrio85==53) | (barrio85==36) | (barrio85==21) | (barrio85==59) | (barrio85==20) | (barrio85==17) | (barrio85==60) | (barrio85==26) | (barrio85==34) | (barrio85==22) | (barrio85==18) | (barrio85==48) | (domdepartamento==19) | (domdepartamento==3)
replace barriodpto=3 if (barrio85==58) | (barrio85==55) | (barrio85==24) | (barrio85==19) | (barrio85==35) | (barrio85==54) | (domdepartamento==6) | (domdepartamento==4)
replace barriodpto=4 if (barrio85==27) | (barrio85==12) | (barrio85==52) | (barrio85==38) | (barrio85==25) | (barrio85==44) | (barrio85==42) | (domdepartamento==8) | (domdepartamento==15) | (domdepartamento==14) | (domdepartamento==9) | (domdepartamento==5)
replace barriodpto=5 if (barrio85==29) | (barrio85==23) | (barrio85==49) | (barrio85==45) | (barrio85==40) | (barrio85==1) | (barrio85==41) | (barrio85==51) | (barrio85==46) | (barrio85==33)
replace barriodpto=6 if (barrio85==47) | (barrio85==4) | (barrio85==2) | (barrio85==5) | (barrio85==43) | (barrio85==9) | (domdepartamento==16) | (domdepartamento==17) | (domdepartamento==18) | (domdepartamento==7)
replace barriodpto=7 if (barrio85==39) | (barrio85==3) | (barrio85==10) | (barrio85==6) | (barrio85==15) | (domdepartamento==11) 
replace barriodpto=8 if (barrio85==50) | (barrio85==11)
replace barriodpto=9 if (barrio85==8) | (barrio85==13)
replace barriodpto=10 if (barrio85==14) | (barrio85==7) | (domdepartamento==12) | (domdepartamento==10)

*** Cantidad de perceptores de ingresos ***

gen wages=bc_ing_lab
gen nonwages=bc_jub_pen+bc_jub_pene+bc_tarjeta+bc_transf_hog+bc_beneficios
gen otroing=bc_ing_cap

gsort bc_correlat -wages -nonwages -otroing

* Identificar al principal sostenedor del hogar *

by bc_correlat: gen principal_sostenedor=cond(_n == 1, 1, .)
replace principal_sostenedor=cond(principal_sostenedor==1, 1, .)

sort bc_correlat perinformante

recode principal_sostenedor (.=0)


gen recibeingresos=.
replace recibeingresos=0 if bc_pe3<14 | (wages==0 | nonwages==0 | otroing==0)
replace recibeingresos=1 if bc_pe3>13 & (wages>0 | nonwages>0 | otroing>0)
egen cantingresos_h=sum(recibeingresos), by(bc_correlat)

gen cantperceptor=.    
replace cantperceptor=0 if (cantingresos_h==1 | cantingresos_h==0) & principal_sostenedor==1
replace cantperceptor=5 if cantingresos_h==2 & principal_sostenedor==1
replace cantperceptor=9 if cantingresos_h==3 & principal_sostenedor==1
replace cantperceptor=11 if cantingresos_h>3 & principal_sostenedor==1 

*** Cantidad de personas en el hogar ***

gen cantpersonas=.
replace cantpersonas=0 if d25==1 & principal_sostenedor==1
replace cantpersonas=3 if d25==2 | d25==3 & principal_sostenedor==1
replace cantpersonas=4 if d25==4 & principal_sostenedor==1
replace cantpersonas=6 if d25>4 & principal_sostenedor==1

*** Menores de hasta 10 años ***

gen menor10=bc_pe3<11
egen menor10hog=sum(menor10), by(bc_correlat)
replace menor10hog=0 if menor10hog==0
replace menor10hog=1 if menor10hog==1
replace menor10hog=2 if menor10hog==2
replace menor10hog=3 if menor10hog>2

gen cantmenores=0
replace cantmenores=2 if (menor10hog==0 | menor10hog==1) & principal_sostenedor==1
replace cantmenores=1 if (menor10hog==2) & principal_sostenedor==1
replace cantmenores=0 if (menor10hog==3) & principal_sostenedor==1

*** Al menos 1 universitario en el hogar ***

gen universitario=nivel_aux==5
egen universitariohog=sum(universitario), by(bc_correlat)
replace universitariohog=0 if universitariohog==0 & principal_sostenedor==1
replace universitariohog=3 if universitariohog>0 & principal_sostenedor==1

*** Nivel educativo del principal sostenedor del hogar ***

gen edusostenedor=.
replace edusostenedor=0 if principal_sostenedor==1 & (nivel_aux==0 | nivel_aux==1)
replace edusostenedor=1 if principal_sostenedor==1 & (nivel_aux==2 | nivel_aux==3 | (nivel_aux==4 & e215_1==2) | (nivel_aux==5 & e218_1==2) | (e51_10>0 & e221_1==2))
replace edusostenedor=3 if principal_sostenedor==1 & ((nivel_aux==5 & e218_1==1) | (nivel_aux==4 & e215_1==1) | (e51_10>0 & e221_1==1))
replace edusostenedor=6 if principal_sostenedor==1 & (e51_11>0)

*** Atención a la salud del principal sostenedor del hogar ***

gen saludsostenedor=.
replace saludsostenedor=0 if principal_sostenedor==1 & (e45_cv==1 | e45_cv==5 | e45_cv==6 | e45_cv==7)
replace saludsostenedor=5 if principal_sostenedor==1 & (e45_cv==4)
replace saludsostenedor=7 if principal_sostenedor==1 & (e45_cv==2)
replace saludsostenedor=8 if principal_sostenedor==1 & (e45_cv==3)

*** Techo de chapa u otro material precario ***

gen techochapa=.
replace techochapa=0 if principal_sostenedor==1 & c3>2
replace techochapa=3 if principal_sostenedor==1 & c3<3

*** Cantidad de baños en la vivienda ***

gen cantbaños=.
replace cantbaños=0 if (d14==0 | d14==1) & principal_sostenedor==1
replace cantbaños=3 if (d14==2) & principal_sostenedor==1
replace cantbaños=7 if (d14>2) & principal_sostenedor==1

*** Auto ***

gen automovil=.
replace automovil=0 if (d21_18==2) & principal_sostenedor==1
replace automovil=4 if (d21_18==1 & d21_18_1==1) & principal_sostenedor==1
replace automovil=7 if (d21_18==1 & d21_18_1>1) & principal_sostenedor==1

*** TV color ***

gen tvcolor=.
replace tvcolor=0 if (d21_4==2 & d21_5==2) & principal_sostenedor==1
replace tvcolor=2 if ((d21_4==1 & d21_4_1==1) | (d21_5==1 & d21_5_1==1)) & principal_sostenedor==1
replace tvcolor=4 if ((d21_4==1 & (d21_4_1==2 | d21_4_1>2)) | (d21_5==1 & (d21_5_1==2 | d21_5_1>2))) & principal_sostenedor==1

*** Heladera ***

gen heladera=.
replace heladera=0 if (d21_3==2) & principal_sostenedor==1
replace heladera=4 if (d21_3==1) & principal_sostenedor==1

*** Aire acondicionado ***

gen aireacond=.
replace aireacond=0 if (d21_14==2) & principal_sostenedor==1
replace aireacond=2 if (d21_14==1) & principal_sostenedor==1

*** TV para abonados ***

gen tvabonados=.
replace tvabonados=0 if (d21_7==2) & principal_sostenedor==1
replace tvabonados=2 if (d21_7==1) & principal_sostenedor==1

*** Streaming (en lugar de DVD, que no se consulta en ECH) ***

gen stream=.
replace stream=0 if (d21_21==2) & principal_sostenedor==1
replace stream=1 if (d21_21==1) & principal_sostenedor==1

*** Computadora ***

gen computadora=.
replace computadora=0 if (d21_15==2 | d21_15_1==1 | d21_15_5==1) & principal_sostenedor==1
replace computadora=2 if (d21_15_3==1 & d21_15_4==1) & principal_sostenedor==1
replace computadora=3 if (d21_15_3==1 & d21_15_4==2) & principal_sostenedor==1
replace computadora=4 if (d21_15_3==1 & d21_15_4>2) & principal_sostenedor==1

*** Lavarropa ***

gen lavarropa=. 
replace lavarropa=0 if (d21_10==2) & principal_sostenedor==1
replace lavarropa=2 if (d21_10==1) & principal_sostenedor==1

*** Lavavajilla ***

gen lavavajilla=.
replace lavavajilla=0 if (d21_12==2) & principal_sostenedor==1
replace lavavajilla=2 if (d21_12==1) & principal_sostenedor==1

*** Microondas ***

gen microondas=.
replace microondas=0 if (d21_13==2) & principal_sostenedor==1
replace microondas=2 if (d21_13==1) & principal_sostenedor==1

*** Teléfono ***

gen telefono=.
replace telefono=0 if (d21_17==2) & principal_sostenedor==1
replace telefono=3 if (d21_17==1) & principal_sostenedor==1

*** Servicio doméstico ***

gen servdomestico=.
replace servdomestico=0 if (d181==2) & principal_sostenedor==1
replace servdomestico=4 if (d230>0 & d230<31) & principal_sostenedor==1
replace servdomestico=7 if (d230>30) & principal_sostenedor==1
replace servdomestico=11 if (d231==1) & principal_sostenedor==1

********** Estratos **********

gen estratos7=barriodpto+cantperceptor+cantpersonas+cantmenores+universitariohog+edusostenedor+saludsostenedor+techochapa+cantbaños+automovil+tvcolor+heladera+aireacond+tvabonados+stream+computadora+lavarropa+lavavajilla+microondas+telefono+servdomestico if principal_sostenedor==1

egen estratos7hog=max(estratos7), by(bc_correlat)
xtile decil_inse=estratos7hog [aw=peso], nq(10)



**************************************
***** VARIABLES PARA LOS MODELOS *****
**************************************

set seed 1234


***** Pasar valor locativo a precios constantes *****

gen vl_cte=bc_pg14*bc_ipc_nuevo


***** Restar el valor locativo del ingreso del hogar *****

gen ht11_cte_svl=bc_ht11_sss-vl_cte 
replace ht11_cte_svl=0 if ht11_cte_svl<0


***** Error de tipeo en cantidad de baños (1 persona 11 baños) *****

replace d14=1 if d14==11


***** Edad, sexo y nivel educativo del jefe/a de hogar *****

gen edadjefe=bc_pe3 if bc_pe4==1
bys bc_correlat: egen edadjefeh=max(edadjefe)

gen sexojefe=sexo if bc_pe4==1
bys bc_correlat: egen sexojefeh=max(sexojefe)

gen primariajefe=primaria if bc_pe4==1
bys bc_correlat: egen primariajefeh=max(primariajefe)
gen secundariajefe=secundaria if bc_pe4==1
bys bc_correlat: egen secundariajefeh=max(secundariajefe)
gen terciariajefe=terciaria if bc_pe4==1
bys bc_correlat: egen terciariajefeh=max(terciariajefe)


***** Cantidad de personas *****

gen cantidadpersonas=d25
drop cantidadpersonas
gen persona=1
bys bc_correlat: egen cantidadpersonas= sum(persona) if bc_pe4!=7

gen jubypensiones1=bc_pg91+bc_pg92 // sumar jubilaciones o pensiones más jubilaciones o pensiones del exterior
*Me quedo con las jubypensiones de jubilados, pensionistas, o ocupados 
*Hay 35 personas que reciben jubilaciones y/o pensiones que tienen otra cond laboral, los excluyo*
*Pasar a precios constantes

gen jubypensiones=jubypensiones1*bc_ipc_nuevo
replace jubypensiones=0 if bc_pobp==1
replace jubypensiones=0 if bc_pobp==3
replace jubypensiones=0 if bc_pobp==4
replace jubypensiones=0 if bc_pobp==5

gen jubypensionista=1 if jubypensiones>0
recode jubypensionista (.=0)
bys bc_correlat: egen jubypen=max(jubypensionista)
bys bc_correlat: egen cantjubypen_aux=sum(jubypensionista)

gen cantjubypen=0
replace cantjubypen=1 if cantjubypen_aux==1
replace cantjubypen=2 if cantjubypen_aux==2 | cantjubypen_aux==3 | cantjubypen_aux==5

gen mayor_18=bc_pe3>17
bys bc_correlat: egen mayores18=sum(mayor_18) if bc_pe4!=7

gen propjubypen= cantjubypen_aux/cantidadpersonas
gen propjubypen18= cantjubypen_aux/mayores18


gen menor_3=bc_pe3<4
bys bc_correlat: egen menores3=max(menor_3)

gen menor_45=(bc_pe3>3 & bc_pe3<6)
bys bc_correlat: egen menores4_5=max(menor_45)

gen menor6_12=(bc_pe3>5 & bc_pe3<13)
bys bc_correlat: egen menores6_12=max(menor6_12)

gen menor13_17=(bc_pe3>12 & bc_pe3<18)
bys bc_correlat: egen menores13_17=max(menor13_17)


***** Cantidad de ocupados en el hogar *****

bys bc_correlat: egen cantocupados=sum(empleo)
gen propocupados18=cantocupados/mayores18


***** Variables asociadas a la vivienda *****

gen techo=c3==1
replace techo=1 if c3==2

gen baño=d14

gen ssdom=.
replace ssdom=1 if d181==1
replace ssdom=0 if d181==2

gen refrigerador=d21_3
replace refrigerador=0 if d21_3==2

gen lavarropa1=d21_10
replace lavarropa1=0 if d21_10==2

gen tvcolor1=0
replace tvcolor1=1 if d21_4==1 | d21_5==1

gen telefono1=d21_17
replace telefono1=0 if d21_17==2

gen compu=d21_15_3
replace compu=0 if d21_15_3==2

gen lavavajilla1=d21_12
replace lavavajilla1=0 if d21_12==2

gen tvabono=d21_7
replace tvabono=0 if d21_7==2

gen micro=d21_13
replace micro=0 if d21_13==2

gen aire=d21_14
replace aire=0 if d21_14==2

gen auto=d21_18
replace auto=0 if d21_18==2


sum refrigerador-auto
pca refrigerador-auto // veo si tengo que usar un solo componente o mas de uno, como comp3 es 0.99 (el 1 me determina el quiebre)
screeplot, yline(1) ci(het) // explica cómo va a pesar cada variable en cada componente
predict confort1 confort2



**********************************************
***** REGRESIONES EN CADA DECIL DEL INSE *****
**********************************************

forvalues i=.05(.1).95 {
local pct=round(`i'*10+.5)
qreg ht11_cte_svl edadjefeh sexojefeh montevideo cantidadpersonas propocupados18 propjubypen18 menores3 menores4_5 menores6_12 menores13_17 ssdom baño techo confort1 confort2 secundariajefeh terciariajefeh tiphog1 tiphog2 tiphog3 tiphog5 if bc_nper==1 & ht11_cte_svl>0, q(`pct')

outreg2 using "$base\ingresoshECH_EUT.xls", append seeout ct(`pct')

est store ingresoest

predict ht11_cte_svl_nn_`pct' if decil_inse==`pct'

predict residuo_`pct' if decil_inse==`pct', residuals
 
}

tabstat residuo_1, s(mean sd n) format(%25.0g)
tabstat residuo_2, s(mean sd n) format(%25.0g)
tabstat residuo_3, s(mean sd n) format(%25.0g)
tabstat residuo_4, s(mean sd n) format(%25.0g)
tabstat residuo_5, s(mean sd n) format(%25.0g)
tabstat residuo_6, s(mean sd n) format(%25.0g)
tabstat residuo_7, s(mean sd n) format(%25.0g)
tabstat residuo_8, s(mean sd n) format(%25.0g)
tabstat residuo_9, s(mean sd n) format(%25.0g)
tabstat residuo_10, s(mean sd n) format(%25.0g)

generate residuo1_i=rnormal(5936.981532814939783, 3439.207435052824167) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==1
generate residuo2_i=rnormal(6509.390813356238141, 4543.130359891451008) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==2
generate residuo3_i=rnormal(7517.602820668051208, 5622.730779812863148) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==3
generate residuo4_i=rnormal(8334.772651859399048, 6748.335855123613328) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==4
generate residuo5_i=rnormal(9193.537751274856419, 7161.805869074077236) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==5
generate residuo6_i=rnormal(10602.10355894878739, 9025.558061273690328) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==6
generate residuo7_i=rnormal(11663.36821905002398, 9235.252906668256401) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==7
generate residuo8_i=rnormal(15285.56366746734966, 15851.59439113987537) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==8
generate residuo9_i=rnormal(21354.7067048828867, 30977.41958008233632) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==9
generate residuo10_i=rnormal(41965.60386821092834, 42650.16522144402552) if bc_nper==1 & ht11_cte_svl>0 & decil_inse==10


forvalues i=1(1)10 {
g ing_hogar_r_`i'=ht11_cte_svl_nn_`i'+residuo`i'_i

}

gsort bc_correlat bc_nper

save "$base\ech2021_2022predicciones", replace



***********************************
********** EUT 2021/2022 **********
***********************************

use "$base\eut2021_2022.dta", clear  


************************************************
***** MODIFICACIÓN Y CREACIÓN DE VARIABLES *****
************************************************


***** Sexo *****

rename p2 sexo
label define sexo 1 "Hombre" 2 "Mujer"
label values sexo sexo


***** Región: Montevideo e interior *****

gen region=0
replace region=1 if domdepartamento==1
replace region=2 if domdepartamento!=1
label define region 1 "Montevideo" 2 "Interior", replace
label values region region

gen montevideo=(region==1)
gen interior=(region==2)


***** Nivel educativo *****

gen nivel_edu=.
replace nivel_edu=1 if (p6==1 | p6==2 | p6==3)
replace nivel_edu=2 if (p6==4 | p6==5)
replace nivel_edu=3 if (p6==6 | p6==7)
label define nivel_edu 1 "Hasta primaria" 2 "Secundaria y UTU" 3 "Terciaria", replace 
label values nivel_edu nivel_edu

gen primaria=(nivel_edu==1)
gen secundaria=(nivel_edu==2)
gen terciaria=(nivel_edu==3)


***** Tipo de hogar *****
*************************

rename p9 e32

*** Variable jefe de hogar ***

gen jefeh=1

*** Variable hijo ***

gen hijo=0
replace hijo=1 if inrange(e32,3,5)
egen hijoh= max(hijo), by (numero)

*** Variable cónyuge ***

gen conyu=0
replace conyu=1 if e32==2
egen conyuh=max(conyu), by (numero)

*** Variable padre/madre/suegro/suegra ***

gen padresue=0  
replace padresue=1 if e32==7 | e32==8
egen padresueh=max(padresue), by (numero)

*** Variable otro familiar ***

gen otrofam=0
replace otrofam=1 if e32==6 | e32==9 | e32==10 | e32==11 | e32==12
egen otrofamh=max(otrofam), by (numero)

*** Variable no familiar ***

gen nofam=0
replace nofam=1 if e32==13 | e32==14
egen nofamh=max(nofam), by (numero)

*** Nuclear monoparental ***

generate tiphog1=0
replace tiphog1=1 if (jefeh==1 & conyuh==0 & hijoh==1 & padresueh==0 & otrofamh==0 & nofamh==0)

*** Nuclear biparental ***

generate tiphog2=0
replace tiphog2=1 if (jefeh==1 & conyuh==1 & hijoh==1 & padresueh==0 & otrofamh==0 & nofamh==0)

*** Compuesto/Extendido ***

generate tiphog3=0
replace tiphog3=1 if (nofamh==1) | ((padresueh==1 | otrofamh==1) & (nofamh==0))

*** Unipersonal ***

generate tiphog4=0
replace tiphog4=1 if ((jefeh==1 & conyuh==0 & padresueh==0 & hijoh==0 & otrofamh==0 & nofamh==0)& e32<14)

*** Parejas sin hijos ***

generate tiphog5=0
replace tiphog5=1 if (jefeh==1 & conyuh==1 & padresueh==0 & hijoh==0 & otrofamh==0 & nofamh==0)

*** Definir variables ***

capture drop
gen tipohogar=.
replace tipohogar=1 if tiphog1==1
replace tipohogar=2 if tiphog2==1
replace tipohogar=3 if tiphog3==1 
replace tipohogar=4 if tiphog4==1
replace tipohogar=5 if tiphog5==1
label define tipohogar 1 "Nuclear monoparental" 2 "Nuclear biparental"  3 "Compuesto/Extendido" 4 "Unipersonal"  5 "Parejas sin hijos"
label values tipohogar tipohogar


***** Condición de actividad *****

foreach var in al1 al2 al3 al11 al12 al15 {
    destring `var', replace ignore("NA")
}

gen codac=3 
replace codac=0 if edad<14
replace codac=1 if (al1==1 | al2==1 | al3==1) 
replace codac=2 if al11==1 | (al11==2 & (al12==2 | al12==3)) 
label define codac 1 "Ocupados" 2 "Desocupados"  3 "Inactivos" 0 "PNET"
label values codac codac

*** Adultos ocupados en el hogar ***

gen ocupados=(codac==1)
egen ocupadosh=sum(ocupados), by(numero)

gen empleo=ocupados


***** Índice socioeconómico (INSE) *****
****************************************

foreach var in inse1 inse1_1 inse1_2 inse1_3 inse1_4 inse3 inse4 inse5_1 inse6 inse7_111 inse7_112 inse7_31 inse7_32 inse7_11 inse7_12 inse7_101 inse7_81 inse7_61 inse7_51 inse7_52 inse7_21 inse7_71 inse7_91 inse7_41 {
    destring `var', replace ignore("NA")
}

*** Barrios de Montevideo y departamentos ***

gen barriodpto=.
replace barriodpto=0 if (barrio85=="Manga, Toledo Chico") | (barrio85=="Casavalle") | (barrio85=="La Paloma, Tomkinson") | (domdepartamento==13)
replace barriodpto=1 if (barrio85=="Baąados de Carrasco") | (barrio85=="Villa Garcia, Manga Rur.") | (barrio85=="Tres Ombues, Victoria") | (barrio85=="Piedras Blancas") | (barrio85=="Las Acacias") | (domdepartamento==2)
replace barriodpto=2 if (barrio85=="Paso de la Arena") | (barrio85=="Manga") | (barrio85=="Conciliacion") | (barrio85=="Casabo, Pajas Blancas") | (barrio85=="Jardines del Hipodromo") | (barrio85=="Colon Centro y Noroeste") | (barrio85=="Pta. Rieles, Bella Italia") | (barrio85=="Maroąas, Parque Guarani") | (barrio85=="Lezica, Melilla") | (barrio85=="Castro, P. Castellanos") | (barrio85=="Peąarol, Lavalleja") | (barrio85=="Ituzaingo") | (barrio85=="Flor de Maroąas") | (barrio85=="Villa Muąoz, Retiro") | (domdepartamento==19) | (domdepartamento==3)
replace barriodpto=3 if (barrio85=="Colon Sureste, Abayuba") | (barrio85=="Nuevo Paris") | (barrio85=="Villa Espaąola") | (barrio85=="Las Canteras") | (barrio85=="Cerro") | (barrio85=="Belvedere") | (domdepartamento==6) | (domdepartamento==4)
replace barriodpto=4 if (barrio85=="Cerrito") | (barrio85=="Malvin Norte") | (barrio85=="Sayago") | (barrio85=="La Teja") | (barrio85=="Mercado Modelo, Bolivar") | (barrio85=="Jacinto Vera") | (barrio85=="Reducto") | (domdepartamento==8) | (domdepartamento==15) | (domdepartamento==14) | (domdepartamento==9) | (domdepartamento==5)
replace barriodpto=5 if (barrio85=="Aires Puros") | (barrio85=="Union") | (barrio85=="La Comercial") | (barrio85=="La Figurita") | (barrio85=="Capurro, Bella Vista") | (barrio85=="Ciudad Vieja") | (barrio85=="Aguada") | (barrio85=="Brazo Oriental") | (barrio85=="Larraąaga") | (barrio85=="Paso de las Duranas")
replace barriodpto=6 if (barrio85=="La Blanqueada") | (barrio85=="Cordon") | (barrio85=="Centro") | (barrio85=="Palermo") | (barrio85=="Atahualpa") | (barrio85=="Buceo") | (domdepartamento==16) | (domdepartamento==17) | (domdepartamento==18) | (domdepartamento==7)
replace barriodpto=7 if (barrio85=="Prado, Nueva Savona") | (barrio85=="Barrio Sur") | (barrio85=="Pque. Batlle, V. Dolores") | (barrio85=="Parque Rodo") | (barrio85=="Carrasco Norte") | (domdepartamento==11) 
replace barriodpto=8 if (barrio85=="Tres Cruces") | (barrio85=="Malvin")
replace barriodpto=9 if (barrio85=="Pocitos") | (barrio85=="Punta Gorda")
replace barriodpto=10 if (barrio85=="Carrasco") | (barrio85=="Punta Carretas") | (domdepartamento==12) | (domdepartamento==10)

*** Cantidad de perceptores de ingresos ***

gen cantperceptor=.    
replace cantperceptor=0 if (inse3==1 | inse3==0) & perinformante==1
replace cantperceptor=5 if inse3==2 & perinformante==1
replace cantperceptor=9 if inse3==3 & perinformante==1
replace cantperceptor=11 if inse3>3 & inse3<7 & perinformante==1 

*** Cantidad de personas en el hogar ***

gen cantpersonas=.
replace cantpersonas=0 if h5==1 & perinformante==1
replace cantpersonas=3 if h5==2 | h5==3 & perinformante==1
replace cantpersonas=4 if h5==4 & perinformante==1
replace cantpersonas=6 if h5>4 & perinformante==1

*** Menores de hasta 10 años ***

gen menor10=edad<11
egen menor10hog=sum(menor10), by(numero)
replace menor10hog=0 if menor10hog==0
replace menor10hog=1 if menor10hog==1
replace menor10hog=2 if menor10hog==2
replace menor10hog=3 if menor10hog>2

gen cantmenores=0
replace cantmenores=2 if (menor10hog==0 | menor10hog==1) & perinformante==1
replace cantmenores=1 if (menor10hog==2) & perinformante==1
replace cantmenores=0 if (menor10hog==3) & perinformante==1

*** Al menos 1 universitario en el hogar ***

gen universitario=nivel_edu==3
egen universitariohog=sum(universitario), by(numero)
replace universitariohog=0 if universitariohog==0 & perinformante==1
replace universitariohog=3 if universitariohog>0 & perinformante==1

*** Nivel educativo del principal sostenedor del hogar ***

gen edusostenedor=.
replace edusostenedor=0 if perinformante==1 & (p6==1 | p6==2 | p6==3)
replace edusostenedor=1 if perinformante==1 & (p6==4 | p6==5 | p6==6)
replace edusostenedor=3 if perinformante==1 & (p6==7)

*** Atención a la salud del principal sostenedor del hogar ***

gen saludsostenedor=.
replace saludsostenedor=0 if inse1_1==1 & perinformante==1
replace saludsostenedor=5 if inse1_2==1 & perinformante==1
replace saludsostenedor=7 if inse1_3==1 & perinformante==1
replace saludsostenedor=8 if inse1_4==1 & perinformante==1

*** Techo de chapa u otro material precario ***

gen techochapa=.
replace techochapa=0 if inse4==1 & perinformante==1
replace techochapa=3 if inse4==2 & perinformante==1

*** Cantidad de baños en la vivienda ***

gen cantbaños=.
replace cantbaños=0 if (inse5_1==0 | inse5_1==1 | inse5_1==.) & perinformante==1
replace cantbaños=3 if (inse5_1==2) & perinformante==1
replace cantbaños=7 if (inse5_1>2 & inse5_1<8) & perinformante==1

*** Auto ***

gen automovil=.
replace automovil=0 if (inse7_111==2) & perinformante==1
replace automovil=4 if (inse7_111==1 & inse7_112==1) & perinformante==1
replace automovil=7 if (inse7_111==1 & (inse7_112==2 | inse7_112==3 | inse7_112==4)) & perinformante==1

*** TV color ***

gen tvcolor=.
replace tvcolor=0 if (inse7_31==2) & perinformante==1
replace tvcolor=2 if (inse7_31==1 & inse7_32==1) & perinformante==1
replace tvcolor=4 if (inse7_31==1 & (inse7_32==2 | inse7_32>2 & inse7_32<7)) & perinformante==1

*** Heladera ***

gen heladera=.
replace heladera=0 if (inse7_11==2) & perinformante==1
replace heladera=4 if (inse7_11==1) & perinformante==1

*** Aire acondicionado ***

gen aireacond=.
replace aireacond=0 if (inse7_101==2) & perinformante==1
replace aireacond=2 if (inse7_101==1) & perinformante==1

*** TV para abonados ***

gen tvabonados=.
replace tvabonados=0 if (inse7_81==2) & perinformante==1
replace tvabonados=2 if (inse7_81==1) & perinformante==1

*** DVD ***

gen dvd=.
replace dvd=0 if (inse7_61==2) & perinformante==1
replace dvd=1 if (inse7_61==1) & perinformante==1

*** Computadora ***

gen computadora=.
replace computadora=0 if (inse7_51==2) & perinformante==1
replace computadora=2 if (inse7_51==1 & inse7_52==1) & perinformante==1
replace computadora=3 if (inse7_51==1 & inse7_52==2) & perinformante==1
replace computadora=4 if (inse7_51==1 & (inse7_52>2 & inse7_52<7)) & perinformante==1

*** Lavarropa ***

gen lavarropa=. 
replace lavarropa=0 if (inse7_21==2) & perinformante==1
replace lavarropa=2 if (inse7_21==1) & perinformante==1

*** Lavavajilla ***

gen lavavajilla=.
replace lavavajilla=0 if (inse7_71==2) & perinformante==1
replace lavavajilla=2 if (inse7_71==1) & perinformante==1

*** Microondas ***

gen microondas=.
replace microondas=0 if (inse7_91==2) & perinformante==1
replace microondas=2 if (inse7_91==1) & perinformante==1

*** Teléfono ***

gen telefono=.
replace telefono=0 if (inse7_41==2) & perinformante==1
replace telefono=3 if (inse7_41==1) & perinformante==1

*** Servicio doméstico ***

gen servdomestico=.
replace servdomestico=0 if (inse6==4) & perinformante==1
replace servdomestico=4 if (inse6==2) & perinformante==1
replace servdomestico=7 if (inse6==1) & perinformante==1
replace servdomestico=11 if (inse6==3) & perinformante==1

*** Estratos ***

gen estratos7= barriodpto+cantperceptor+cantpersonas+cantmenores+universitariohog+edusostenedor+saludsostenedor+techochapa+cantbaños+automovil+tvcolor+heladera+aireacond+tvabonados+dvd+computadora+lavarropa+lavavajilla+microondas+telefono+servdomestico if perinformante==1

egen estratos7hog= max(estratos7), by(numero)
xtile decil_inse=estratos7hog [aw=w], nq(10)



**************************************
***** VARIABLES PARA LOS MODELOS *****
**************************************


***** Edad, sexo y nivel educativo del jefe/a de hogar *****

gen edadjefe=edad if e32==1
bys numero: egen edadjefeh= max(edadjefe)

gen sexojefe=sexo if e32==1
bys numero: egen sexojefeh= max(sexojefe)

gen primariajefe=primaria if e32==1
bys numero: egen primariajefeh=max(primariajefe)
gen secundariajefe= secundaria if e32==1
bys numero: egen secundariajefeh=max(secundariajefe)
gen terciariajefe= terciaria if e32==1
bys numero: egen terciariajefeh=max(terciariajefe)


***** Cantidad de personas *****

gen cantidadpersonas=h5 

gen jubypensionistas=1 if al15==1

bys numero: egen jubypen=max(jubypensionistas)
bys numero: egen cantjubypen_aux=sum(jubypensionistas)

gen cantjubypen=0
replace cantjubypen=1 if cantjubypen_aux==1
replace cantjubypen=2 if cantjubypen_aux==2 | cantjubypen_aux==3 | cantjubypen_aux==4

gen mayor_18=edad>17
bys numero: egen mayores18=sum(mayor_18)

gen propjubypen=cantjubypen_aux/cantidadpersonas
gen propjubypen18=cantjubypen_aux/mayores18

gen menores3=0
replace menores3=1 if h7==1 | h7==2

gen menores4_5=0
replace menores4_5=1 if h8==1 | h8==2

gen menores6_12= 0
replace menores6_12=1 if h9==1 | h9==2 | h9==3 | h9==4

gen menores13_17= edad>12 & edad<18


***** Cantidad de ocupados en el hogar *****

bys numero: egen cantocupados=sum(empleo)

gen propocupados18= cantocupados/mayores18

recode inse3 (.=0)
bys numero: egen cantperceptores=max(inse3)


***** Variables asociadas a la vivienda *****

recode inse4 (.=0)
bys numero: egen techo_aux=max(inse4)

gen techo=.
replace techo=1 if techo_aux==2
replace techo=0 if techo_aux==1

bys numero: egen baño=max(inse5_1)

recode al1 (.=0)
bys numero: egen ssdom_aux= max(inse6)
gen ssdom=.
replace ssdom=1 if ssdom_aux==1 | ssdom_aux==2 | ssdom_aux==3
replace ssdom=0 if ssdom_aux==4

recode inse7_11 (.=0)
bys numero: egen refrigerador_aux=max(inse7_11)

gen refrigerador=0
replace refrigerador=1 if refrigerador_aux==1

recode inse7_21 (.=0)
bys numero: egen lavarropa_aux=max(inse7_21)

gen lavarropa1=0
replace lavarropa1=1 if lavarropa_aux==1

recode inse7_31 (.=0)
bys numero: egen tvcolor_aux=max(inse7_31)

gen tvcolor1=0
replace tvcolor1=1 if tvcolor_aux==1

recode inse7_41 (.=0)
bys numero: egen telef_aux=max(inse7_41)

gen telefono1=0
replace telefono1=1 if telef_aux==1

recode inse7_51 (.=0)
bys numero: egen compu_aux=max(inse7_51)

gen compu=0
replace compu=1 if compu_aux==1

recode inse7_71 (.=0)
bys numero: egen lavavajilla_aux=max(inse7_71)

gen lavavajilla1=0
replace lavavajilla1=1 if lavavajilla_aux==1

recode inse7_81 (.=0)
bys numero: egen tvabono_aux=max(inse7_81)

gen tvabono=0
replace tvabono=1 if tvabono_aux==1

recode inse7_91 (.=0)
bys numero: egen micro_aux=max(inse7_91)

gen micro=0
replace micro=1 if micro_aux==1

recode inse7_101 (.=0)
bys numero: egen aire_aux=max(inse7_101)

gen aire=0
replace aire=1 if aire_aux==1

recode inse7_111 (.=0)
bys numero: egen auto_aux=max(inse7_111)

gen auto=0
replace auto=1 if auto_aux==1


sum refrigerador-auto
pca refrigerador-auto // veo si tengo que usar un solo componente o mas de uno, como comp3 es 0.99 (el 1 me determina el quiebre)
screeplot, yline(1) ci(het) // explica cómo va a pesar cada variable en cada componente
predict confort1 confort2



**********************************
********** PREDICCIONES **********
**********************************


est restore ingresoest

forvalues i=1(1)10 {
predict ingresoest_`i' if perinformante==1 & decil_inse==`i'
replace ingresoest_`i'=0 if ingresoest_`i'==. | ingresoest_`i'<0
 
}

generate residuo1_i=rnormal(5936.981532814939783, 3439.207435052824167) if perinformante==1 & decil_inse==1
generate residuo2_i=rnormal(6509.390813356238141, 4543.130359891451008) if perinformante==1 & decil_inse==2
generate residuo3_i=rnormal(7517.602820668051208, 5622.730779812863148) if perinformante==1 & decil_inse==3
generate residuo4_i=rnormal(8334.772651859399048, 6748.335855123613328) if perinformante==1 & decil_inse==4
generate residuo5_i=rnormal(9193.537751274856419, 7161.805869074077236) if perinformante==1 & decil_inse==5
generate residuo6_i=rnormal(10602.10355894878739, 9025.558061273690328) if perinformante==1 & decil_inse==6
generate residuo7_i=rnormal(11663.36821905002398, 9235.252906668256401) if perinformante==1 & decil_inse==7
generate residuo8_i=rnormal(15285.56366746734966, 15851.59439113987537) if perinformante==1 & decil_inse==8
generate residuo9_i=rnormal(21354.7067048828867, 30977.41958008233632) if perinformante==1 & decil_inse==9
generate residuo10_i=rnormal(41965.60386821092834, 42650.16522144402552) if perinformante==1 & decil_inse==10


forvalues i = 1(1)10 {
g ingresoest_r`i'=ingresoest_`i'+residuo`i'_i
replace ingresoest_r`i'=0 if ingresoest_r`i'==. | ingresoest_r`i'<0

}

gen ingresoest=ingresoest_1+ingresoest_2+ingresoest_3+ingresoest_4+ingresoest_5+ingresoest_6+ingresoest_7+ingresoest_8+ingresoest_9+ingresoest_10
replace ingresoest=0 if ingresoest<0

gen ingresoest_r=ingresoest_r1+ingresoest_r2+ingresoest_r3+ingresoest_r4+ingresoest_r5+ingresoest_r6+ingresoest_r7+ingresoest_r8+ingresoest_r9+ingresoest_r10
replace ingresoest_r=0 if ingresoest_r<0

rename ingresoest_r ing_reginse


save "$base\eut2021_2022procesada", replace



*************************************************************
***** IMPUTACIÓN CON REGRESIONES EN CADA DECIL DEL INSE *****
*************************************************************

clear all
set more off
   
local user=1 // 1=Paula

if `user'==1 {
global base "C:\Users\Paula Barro\Dropbox\Paula"
}

use "$base\ech2021_2022predicciones.dta", clear  
append using "eut2021_2022procesada.dta", force
recode ech (.=0)


sum ht11_cte_svl if bc_nper==1 & ech==1 [aw=peso]
sum ingresoest if perinformante==1 & ech==0 [aw=w]
sum ing_reginse if perinformante==1 & ech==0 [aw=w]


twoway kdensity ht11_cte_svl if bc_nper==1 & ht11_cte_svl<200000 & ech==1 [aw=peso], lcolor (ebblue)  || kdensity ingresoest if perinformante==1 & ingresoest<200000 & ech==0 [aw=w], lcolor (purple)lpattern(dash_dot)|| kdensity ing_reginse if perinformante==1 & ing_reginse<200000 & ech==0 [aw=w], lcolor (black)lpattern(dash)   ti("Ingreso del hogar en pesos", size(medium))  legend(order(1 "En ECH original" 2 "Imputado en EUT con regresiones en cada decil del INSE" 3 "Imputado en EUT con residuo, con regresiones en cada decil del INSE") position(6) rows(3) size(medsmall)) graphregion(color(white)) xtitle("") xlabel(0(50000)200000,labsize(small)) ylabel(0(0.00002)0.00008 ,labsize(small))

save "$base\imput_reginse", replace


keep if perinformante==1 & ech==0

preserve
expand w
egen masa_hogar=sum(ing_reginse)
format masa_hogar %9.0f
sum masa_hogar
local total=r(mean)
restore
tab `total'

preserve
expand w
egen masa_hogar=sum(ing_reginse), by(decil_inse)
format masa_hogar %10.0f
tabstat masa_hogar, by(decil_inse) format(%12.0f)
restore

preserve
expand w
egen masa_hogar=mean(ing_reginse), by(decil_inse)
format masa_hogar %10.0f
tabstat masa_hogar, by(decil_inse) format(%12.0f)
restore


